# mypy-boto3-support

[![PyPI - mypy-boto3-support](https://img.shields.io/pypi/v/mypy-boto3-support.svg?color=blue)](https://pypi.org/project/mypy-boto3-support)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-support.svg?color=blue)](https://pypi.org/project/mypy-boto3-support)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-support?color=blue)](https://pypistats.org/packages/mypy-boto3-support)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Support 1.17.68](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/support.html#Support)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-support docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_support/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-support](#mypy-boto3-support)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `Support` service.

```bash
python -m pip install boto3-stubs[support]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[support]` in your environment:
  `python -m pip install 'boto3-stubs[support]'`

Both type checking and auto-complete should work for `Support` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[support]` in your environment:
  `python -m pip install 'boto3-stubs[support]'`

Both type checking and auto-complete should work for `Support` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[support]` in your environment:
  `python -m pip install 'boto3-stubs[support]'`
- Run `mypy` as usual

Type checking should work for `Support` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[support]` in your environment:
  `python -m pip install 'boto3-stubs[support]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Support` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`SupportClient` provides annotations for `boto3.client("support")`.

```python
import boto3

from mypy_boto3_support import SupportClient

client: SupportClient = boto3.client("support")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SupportClient = session.client("support")
```

### Paginators annotations

`mypy_boto3_support.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_support import SupportClient
from mypy_boto3_support.paginator import (
    DescribeCasesPaginator,
    DescribeCommunicationsPaginator,
)

client: SupportClient = boto3.client("support")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
```

### Literals

`mypy_boto3_support.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_support.literals import (
    DescribeCasesPaginatorName,
    DescribeCommunicationsPaginatorName,
)

def check_value(value: DescribeCasesPaginatorName) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_support.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_support.type_defs import (
    AddAttachmentsToSetResponseTypeDef,
    AddCommunicationToCaseResponseTypeDef,
    AttachmentDetailsTypeDef,
    AttachmentTypeDef,
    CaseDetailsTypeDef,
    CategoryTypeDef,
    CommunicationTypeDef,
    CreateCaseResponseTypeDef,
    DescribeAttachmentResponseTypeDef,
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsResponseTypeDef,
    DescribeServicesResponseTypeDef,
    DescribeSeverityLevelsResponseTypeDef,
    DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef,
    DescribeTrustedAdvisorCheckResultResponseTypeDef,
    DescribeTrustedAdvisorCheckSummariesResponseTypeDef,
    DescribeTrustedAdvisorChecksResponseTypeDef,
    PaginatorConfigTypeDef,
    RecentCaseCommunicationsTypeDef,
    RefreshTrustedAdvisorCheckResponseTypeDef,
    ResolveCaseResponseTypeDef,
    ServiceTypeDef,
    SeverityLevelTypeDef,
    TrustedAdvisorCategorySpecificSummaryTypeDef,
    TrustedAdvisorCheckDescriptionTypeDef,
    TrustedAdvisorCheckRefreshStatusTypeDef,
    TrustedAdvisorCheckResultTypeDef,
    TrustedAdvisorCheckSummaryTypeDef,
    TrustedAdvisorCostOptimizingSummaryTypeDef,
    TrustedAdvisorResourceDetailTypeDef,
    TrustedAdvisorResourcesSummaryTypeDef,
)

def get_structure() -> AddAttachmentsToSetResponseTypeDef:
    return {
      ...
    }
```
